class State:
    def __init__(self):
        self.buffer = ''

from .link import LinkText
from .link import LinkUrl
from .inlinecode import InlineCode
from .text import Text
from .title import Title
from .image import Image
from .tick import Tick
from .codeblock import CodeBlock
from .link import Link